var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import 'isomorphic-fetch';
import Frisbee from 'frisbee';
export var V3;
(function (V3) {
    'use strict';
    const ACCESS_TOKEN = 'qjP1UJavDqPSkDSBxz6r';
    const api = new Frisbee({
        baseURI: 'https://gitlab.com/api/v3',
        headers: {
            'PRIVATE-TOKEN': ACCESS_TOKEN
        }
    });
    function getProjects() {
        return new Promise((resolve, reject) => {
            api.get('/projects?owned=true').then(result => {
                resolve(result.body);
            });
        });
    }
    V3.getProjects = getProjects;
    function getProject(name) {
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            const projects = yield getProjects();
            const matchingProjects = projects.filter(project => (name === project.name));
            if (matchingProjects.length > 0) {
                resolve(matchingProjects[0]);
            }
            else {
                reject(undefined);
            }
        }));
    }
    V3.getProject = getProject;
    function getActiveMilestones(projectId) {
        return new Promise((resolve, reject) => {
            api.get(`/projects/${projectId}/milestones?state=active`).then(result => {
                resolve(result.body.map(item => {
                    let mileStone = {
                        id: '',
                        title: '',
                        description: '',
                        dueDate: undefined,
                        startDate: undefined
                    };
                    mileStone.id = item.id;
                    mileStone.title = item.title;
                    mileStone.description = item.description;
                    mileStone.dueDate = new Date(item.due_date);
                    mileStone.startDate = new Date(item.start_date);
                    return mileStone;
                }));
            });
        });
    }
    V3.getActiveMilestones = getActiveMilestones;
    function getCurrentMilestone(projectId, date) {
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            let activeMilestones = yield getActiveMilestones(projectId);
            let currentMilestone = activeMilestones.reduce((aggregate, milestone) => {
                if (milestone.dueDate >= date) {
                    if (!aggregate || aggregate.dueDate > milestone.dueDate) {
                        aggregate = milestone;
                    }
                }
                return aggregate;
            }, undefined);
            currentMilestone ? resolve(currentMilestone) : reject(undefined);
        }));
    }
    V3.getCurrentMilestone = getCurrentMilestone;
    function getMilestoneIssues(projectId, mileStoneId) {
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            api.get(`/projects/${projectId}/milestones/${mileStoneId}/issues`).then(result => {
                resolve(result.body);
            });
        }));
    }
    V3.getMilestoneIssues = getMilestoneIssues;
    function getTimeStatus(projectId, issueId) {
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            let notes = yield getComments(projectId, issueId);
            let progressRegex = /#progress( *)(:?)( *)\d*%/g;
            let progress = notes.filter(note => note.body && note.body.match(progressRegex))
                .sort((a, b) => a.createdAt.getTime() - b.createdAt.getTime())
                .reduce((accumulate, note) => {
                return accumulate.concat(note.body.match(progressRegex));
            }, [])
                .reduce((accumulate, individualProgress) => {
                console.log(individualProgress);
                return accumulate.concat(individualProgress.match(/\d*%/g));
            }, []);
            console.log(progress);
            resolve(progress);
        }));
    }
    V3.getTimeStatus = getTimeStatus;
    function getComments(projectId, issueId) {
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            api.get(`/projects/${projectId}/issues/${issueId}/notes`).then(result => {
                resolve(result.body.map(note => {
                    let newNote = Object.assign({}, note);
                    newNote.createdAt = new Date(note.created_at);
                    return newNote;
                }));
            });
        }));
    }
    V3.getComments = getComments;
})(V3 || (V3 = {}));
//# sourceMappingURL=version-3.js.map