import { service } from './service';
import { SortOrder, Orderby, Scope } from '../models';
import { REST } from '../common';
const urlencode = require('urlencode');
export var Issues;
(function (Issues) {
    function getAll(state = undefined, scope = Scope.ALL, labels = undefined, milestoneTitle = undefined, orderBy = Orderby.CREATED_AT, sort = SortOrder.DESCENDING, search = undefined, milestoneIds = undefined, authoredBy = undefined, assignedTo = undefined) {
        let params = [];
        params.push(REST.QueryParam.createQuery('state', state));
        params.push(REST.QueryParam.createQuery('scope', scope));
        params.push(REST.QueryParam.createQuery('labels', labels ? labels.join(',') : undefined));
        params.push(REST.QueryParam.createQuery('milestone', milestoneTitle));
        params.push(REST.QueryParam.createQuery('order_by', orderBy));
        params.push(REST.QueryParam.createQuery('sort', sort));
        params.push(REST.QueryParam.createQuery('search', search));
        params.push(...(milestoneIds || []).map(iid => REST.QueryParam.createQuery('iids[]', iid)));
        params.push(REST.QueryParam.createQuery('author_id', authoredBy));
        params.push(REST.QueryParam.createQuery('assignee_id', assignedTo));
        return new Promise((resolve, reject) => {
            service.get(`/issues?${REST.QueryParam.join(params)}`)
                .then((result) => resolve(result.body))
                .catch((error) => reject(error));
        });
    }
    Issues.getAll = getAll;
    function getAllOfProject(projectId, state = undefined, scope = Scope.ALL, labels = undefined, milestoneTitle = undefined, sort = SortOrder.DESCENDING, search = undefined, milestoneIds = undefined, authoredBy = undefined, assignedTo = undefined) {
        let params = [];
        params.push(REST.QueryParam.createQuery('state', state));
        params.push(REST.QueryParam.createQuery('scope', scope));
        params.push(REST.QueryParam.createQuery('labels', labels ? labels.join(',') : undefined));
        params.push(REST.QueryParam.createQuery('milestone', milestoneTitle));
        params.push(REST.QueryParam.createQuery('sort', sort));
        params.push(REST.QueryParam.createQuery('search', search));
        params.push(...(milestoneIds || []).map(iid => REST.QueryParam.createQuery('iids[]', iid)));
        params.push(REST.QueryParam.createQuery('author_id', authoredBy));
        params.push(REST.QueryParam.createQuery('assignee_id', assignedTo));
        return new Promise((resolve, reject) => {
            service.get(`/projects/${projectId}/issues?${REST.QueryParam.join(params)}`)
                .then((result) => resolve(result.body))
                .catch((error) => reject(error));
        });
    }
    Issues.getAllOfProject = getAllOfProject;
    function getOneOfProject(projectId, issueId) {
        return new Promise((resolve, reject) => {
            service.get(`/projects/${projectId}/issues/${issueId}`)
                .then((result) => resolve(result.body))
                .catch((error) => reject(error));
        });
    }
    Issues.getOneOfProject = getOneOfProject;
    function create(projectId, title, description, confidential = false, assigneeIds, milestoneId, labels, dueDate) {
        let params = [];
        params.push(REST.QueryParam.createQuery('title', title));
        params.push(REST.QueryParam.createQuery('description', description && urlencode(description)));
        params.push(REST.QueryParam.createQuery('confidential', confidential.toString()));
        params.push(REST.QueryParam.createQuery('milestone_id', milestoneId));
        params.push(REST.QueryParam.createQuery('labels', labels && labels.join(',')));
        params.push(REST.QueryParam.createQuery('due_date', dueDate && dueDate.toDateString()));
        return new Promise((resolve, reject) => {
            service.post(`/projects/${projectId}/issues?${REST.QueryParam.join(params)}`)
                .then((result) => resolve(result.body))
                .catch((error) => reject(error));
        });
    }
    Issues.create = create;
    function edit(projectId, issueId, title, description, confidential = false, assigneeIds, milestoneId, labels, dueDate, event) {
        let params = [];
        params.push(REST.QueryParam.createQuery('title', title));
        params.push(REST.QueryParam.createQuery('description', description && urlencode(description)));
        params.push(REST.QueryParam.createQuery('confidential', confidential.toString()));
        params.push(REST.QueryParam.createQuery('milestone_id', milestoneId));
        params.push(REST.QueryParam.createQuery('labels', labels && labels.join(',')));
        params.push(REST.QueryParam.createQuery('due_date', dueDate && dueDate.toDateString()));
        params.push(REST.QueryParam.createQuery('state_event', event));
        return new Promise((resolve, reject) => {
            service.put(`/projects/${projectId}/issues/${issueId}?${REST.QueryParam.join(params)}`)
                .then((result) => resolve(result.body))
                .catch((error) => reject(error));
        });
    }
    Issues.edit = edit;
    function deleteOne(projectId, issueId) {
        return new Promise((resolve, reject) => {
            service.put(`/projects/${projectId}/issues/${issueId}`)
                .then((result) => resolve(result.body))
                .catch((error) => reject(error));
        });
    }
    Issues.deleteOne = deleteOne;
    ;
})(Issues || (Issues = {}));
//# sourceMappingURL=issues.js.map