import { service } from './service';
import { REST } from '../common';
export var ProjectMilestones;
(function (ProjectMilestones) {
    function getAll(projectId, state = undefined, search = undefined, milestoneIds = undefined) {
        let params = [];
        params.push(REST.QueryParam.createQuery('state', state));
        params.push(REST.QueryParam.createQuery('search', search));
        params.push(...(milestoneIds || []).map(iid => REST.QueryParam.createQuery('iids[]', iid)));
        return new Promise((resolve, reject) => {
            service.get(`/projects/${projectId}/milestones?${REST.QueryParam.join(params)}`)
                .then((result) => resolve(result.body))
                .catch((error) => reject(error));
        });
    }
    ProjectMilestones.getAll = getAll;
    function getOne(projectId, milestoneId) {
        return new Promise((resolve, reject) => {
            service.get(`/projects/${projectId}/milestones/${milestoneId}`)
                .then((result) => resolve(result.body))
                .catch((error) => reject(error));
        });
    }
    ProjectMilestones.getOne = getOne;
    function create(projectId, title, description, dueDate, startDate) {
        let params = [];
        params.push(REST.QueryParam.createQuery('title', title));
        params.push(REST.QueryParam.createQuery('description', description));
        params.push(REST.QueryParam.createQuery('due_date', dueDate && dueDate.toDateString()));
        params.push(REST.QueryParam.createQuery('start_date', startDate && startDate.toDateString()));
        return new Promise((resolve, reject) => {
            service.post(`/projects/${projectId}/milestones?${params.join('&')}`)
                .then((result) => resolve(result.body))
                .catch((error) => reject(error));
        });
    }
    ProjectMilestones.create = create;
    function edit(projectId, milestoneId, title, description, dueDate, startDate, stateEvent) {
        let params = [];
        params.push(REST.QueryParam.createQuery('title', title));
        params.push(REST.QueryParam.createQuery('description', description));
        params.push(REST.QueryParam.createQuery('due_date', dueDate && dueDate.toDateString()));
        params.push(REST.QueryParam.createQuery('start_date', startDate && startDate.toDateString()));
        params.push(REST.QueryParam.createQuery('state_event', stateEvent));
        return new Promise((resolve, reject) => {
            service.post(`/projects/${projectId}/milestones/${milestoneId}?${params.join('&')}`)
                .then((result) => resolve(result.body))
                .catch((error) => reject(error));
        });
    }
    ProjectMilestones.edit = edit;
    function getIssues(projectId, milestoneId) {
        return new Promise((resolve, reject) => {
            service.get(`/projects/${projectId}/milestones/${milestoneId}/issues`)
                .then((result) => resolve(result.body))
                .catch((error) => reject(error));
        });
    }
    ProjectMilestones.getIssues = getIssues;
})(ProjectMilestones || (ProjectMilestones = {}));
//# sourceMappingURL=project-milestones.js.map